git_revision

Macro git_revision 

macro_rules! git_revision {
    () => { ... };
}
Defines constant that holds the git revision at build time.

GIT_REVISION: The git revision as specified by the GIT_REVISION env variable provided at compile time, or the current git revision as discovered by running git describe. GIT_FULL_SHA_REVISION: The full git revision as specified by the GIT_REVISION env variable provided at compile time, or the current git revision as discovered by running git describe.

Note: This macro must only be used from a binary, if used inside a library this will fail to compile.