macro_rules! bin_version {
() => { ... };
}Expand description
Define constants that hold the git revision and package versions.
Defines two global consts:
GIT_REVISION: The git revision as specified by the GIT_REVISION env variable provided at
compile time, or the current git revision as discovered by running git describe.
VERSION: The value of the CARGO_PKG_VERSION environment variable concatenated with the
value of GIT_REVISION.
Note: This macro must only be used from a binary, if used inside a library this will fail to compile.